@@ -22,6 +22,6 @@ def search_view(request):
     owner = request.user.username
     nbids = [res["nbid"] for res in result0 if res["owner"] == owner]
     nbs = Notebook.objects.filter(guid__in=nbids, owner=request.user).order_by("created_time")
-    results = [[e.guid, e.title, e.system, e.last_modified_time().strftime("%Y-%m-%d %H:%M:%S"), e.location] for e in nbs]
+    results = [[e.guid, e.title, e.backend.all()[0].engine_type.name, e.last_modified_time().strftime("%Y-%m-%d %H:%M:%S"), e.location] for e in nbs]
     jsobj = json.dumps({"query":q, "results":results})
     return HttpResponse(jsobj, mimetype='application/json')
