@@ -12,6 +12,17 @@
 */
 
 
+// The JQuery version -  $(window).bind('beforeunload', function() {} );
+// does not work in FF (jquery 1.2).
+// Not sure if this needs to be registered with the delegator
+window.onbeforeunload = function() {
+    if (Notebook.Save.hasUnsavedChanges()) {
+        return 'You have unsaved changes that will be lost.';
+    }
+};
+
+
+
 Notebook.Delegator = function(nodeid) {
     this.mode = 'normal';
     this.listener = nodeid;
@@ -491,7 +502,7 @@ spawnerDownArrowAction.handler = function(e) {
 };
 
 bracketKeyDelete = new Notebook.Action('backkeydel');
-bracketKeyDelete.keyCodes = [46];
+bracketKeyDelete.keyCodes = [46,8];
 bracketKeyDelete.type = 'keydown';
 bracketKeyDelete.handler = function(e) {
     Notebook.bracketSelector.deleteSelections();
@@ -573,6 +584,9 @@ Notebook.__init__.Delegator = function() {
             },
             'toinput': function(t) {
                 Notebook.bracketSelector.modifySelectionStyle('input');
+            },
+            'delete': function(t) {
+                Notebook.bracketSelector.deleteSelections();
             }
         },
         onContextMenu: function(e) {
@@ -605,7 +619,7 @@ Notebook.__init__.Delegator = function() {
     $('#titlecontainer').click(Util.startChangeTitle);
     $('#savebutton').click(function(e){Notebook.Save.save()});
     $('#saveclosebutton').click(function(e){Notebook.Save.saveAndClose()});
-    $('#interruptbutton').click(function(e){Notebook.Async.signalKernel('interupt')});
+    $('#interruptbutton').click(function(e){Notebook.Async.signalKernel('interrupt')});
     $('#killkernelbutton').click(function(e){Notebook.Async.signalKernel('kill')});
 };
 
